@@ -5,7 +5,7 @@ import platform
 from threading import Thread
 from time import sleep
 import socketio
-from aiortc import RTCPeerConnection, RTCRtpSender, RTCConfiguration, RTCIceServer
+from aiortc import RTCPeerConnection, RTCRtpSender, RTCConfiguration, RTCIceServer, RTCSessionDescription
 from aiortc.contrib.media import MediaPlayer, MediaRelay
 import picamera
 
@@ -78,20 +78,20 @@ class GSPeerConnectionBroadcaster:
             async def connect():
                 self._logger.info('connection established')
 
+
             @self.sio.event
-            async def answer(id, description):
+            async def watcher(id, description):
                 if type(description) == str:
                     description = ast.literal_eval(description)
                 desc = type('new_dict', (object,), description)
-                await self.peerConnections[id].setRemoteDescription(desc)
 
-            @self.sio.event
-            async def watcher(id):
+                self._logger.info(str(description["sdp"]))
+                offer = RTCSessionDescription(sdp=description["sdp"], type=description["type"])
+
                 self._logger.info(str(self.rtconfiList))
+
                 if len(self.rtconfiList) > 0:
-                    pc = RTCPeerConnection(configuration=RTCConfiguration(
-                        self.rtconfiList
-                    ))
+                    pc = RTCPeerConnection(configuration=RTCConfiguration(self.rtconfiList))
                 else:
                     pc = RTCPeerConnection()
 
@@ -99,11 +99,10 @@ class GSPeerConnectionBroadcaster:
 
                 video = self.getPiH264Relay()
 
-                @pc.on("iceconnectionstatechange")
-                async def on_iceconnectionstatechange():
-                    # self._logger.info("ICE connection state is %s", pc.iceConnectionState)
-                    if pc.iceConnectionState == "failed":
-                        video_trackList.remove(video)
+                @pc.on("connectionstatechange")
+                async def on_connectionstatechange():
+                    print("Connection state is %s" % pc.connectionState)
+                    if pc.connectionState == "failed":
                         await pc.close()
                         self.peerConnections.pop(id, None)
 
@@ -117,11 +116,15 @@ class GSPeerConnectionBroadcaster:
                     if t.kind == "video":
                         pc.addTrack(video)
 
-                await pc.setLocalDescription(await pc.createOffer())
-                await self.sio.emit("offer", {"id": id,
-                                              "message": json.dumps(
-                                                  {"type": pc.localDescription.type,
-                                                   "sdp": pc.localDescription.sdp})})
+                await pc.setRemoteDescription(offer)
+
+                answer = await pc.createAnswer()
+                await pc.setLocalDescription(answer)
+
+                await self.sio.emit("answer", {"id": id,
+                                               "message": json.dumps(
+                                                   {"type": pc.localDescription.type,
+                                                    "sdp": pc.localDescription.sdp})})
 
             @self.sio.event
             async def disconnectPeer(id):
